@@ -27,7 +27,7 @@ logger = logging.getLogger("nexgen.NeXusGenerator")
 scopes = freephil.parse(
     """
     include scope nexgen.command_line.nxs_phil.goniometer_scope
-    include scope nexgen.command_line.nxs_phil.beamline_scope
+    include scope nexgen.command_line.nxs_phil.instrument_scope
     include scope nexgen.command_line.nxs_phil.detector_scope
     include scope nexgen.command_line.nxs_phil.module_scope
     """,
